﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using PWTutorial.Data;

namespace PWTutorial
{
    public static class GestaoArtigos
    {
        public static void NovoArtigo(String titulo, String texto, String observacoes, String autorNome)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(titulo)) throw new ArgumentNullException();
            if (String.IsNullOrEmpty(texto)) throw new ArgumentNullException();
            if (String.IsNullOrEmpty(autorNome)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Pesquisa na base de dados se já existem artigos com o titulo do argumento
                var listaArtigos = from i in database.Artigos where i.Titulo == titulo select i;

                // Verifica se o artigo ja existe
                if (listaArtigos.Count() > 0)
                {
                    throw new ArgumentException("O artigo já existe.");
                }

                // Procura na base de dados o autor do artigo
                var listaUtilizadores = from i in database.Utilizadores where i.Nome == autorNome select i;

                // Verifica se o utilizador existe
                if (listaUtilizadores.Count() != 1)
                {
                    throw new ArgumentException("O utilizador com o nome " + autorNome + " não existe.");
                }

                var autor = listaUtilizadores.First();


                // Cria um novo artigo
                Artigos novoArtigo = new Artigos();
                novoArtigo.Titulo = titulo;
                novoArtigo.Texto = texto;
                novoArtigo.Observacoes = observacoes;
                novoArtigo.Utilizadores = autor;

                // Coloca o utilizador no nosso entity model
                database.AddToArtigos(novoArtigo);
                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }

        public static void RemoverArtigo(String titulo)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(titulo)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Procura na base de dados o artigo que se pretende apagar
                var listaArtigos = from i in database.Artigos where i.Titulo == titulo select i;

                // Verifica se o artigo existe
                if (listaArtigos.Count() != 1)
                {
                    throw new ArgumentException("O artigo com o titulo " + titulo + " não existe.");
                }

                // Obtem o utilizador da lista de artigos obtida na pesquisa, como sabemos que só poderá ser 1 então podemos dizer que
                // queremos o primeiro artigo da lista.
                var artigo = listaArtigos.First();

                // Apaga o artigo do entity model
                database.DeleteObject(artigo);
                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }

        public static void EditarArtigo(String titulo, String texto, String observacoes, String autorNome)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(titulo)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Procura na base de dados o artigo que se pretende apagar
                var listaArtigos = from i in database.Artigos where i.Titulo == titulo select i;

                // Verifica se o artigo existe
                if (listaArtigos.Count() != 1)
                {
                    throw new ArgumentException("O artigo com o titulo " + titulo + " não existe.");
                }

                // Procura na base de dados o autor do artigo
                var listaUtilizadores = from i in database.Utilizadores where i.Nome == autorNome select i;

                // Verifica se o utilizador existe
                if (listaUtilizadores.Count() != 1)
                {
                    throw new ArgumentException("O utilizador com o nome " + autorNome + " não existe.");
                }

                var autor = listaUtilizadores.First();

                // Obtem o utilizador da lista de artigos obtida na pesquisa, como sabemos que só poderá ser 1 então podemos dizer que
                // queremos o primeiro artigo da lista.
                var artigo = listaArtigos.First();

                // Efectua as alteracoes no artigo
                artigo.Titulo = titulo;
                artigo.Texto = texto;
                artigo.Observacoes = observacoes;
                artigo.Utilizadores = autor;

                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }
    }
}
