﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using PWTutorial.Data;

namespace PWTutorial
{
    public static class GestaoUtilizadores
    {
        public static void AdicionarUtilizador(String nome, String password, String comentarios)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(nome)) throw new ArgumentNullException();
            if (String.IsNullOrEmpty(password)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Pesquisa na base de dados se já existem utilizadores com o nome de utilizador do argumento
                var listaUtilizadores = from i in database.Utilizadores where i.Nome == nome select i;

                // Verifica se o utilizador ja existe
                if (listaUtilizadores.Count() > 0)
                {
                    throw new ArgumentException("O utilizador já existe.");
                }

                // Cria um novo utilizador
                Utilizadores novoUtilizador = new Utilizadores();
                novoUtilizador.Nome = nome;
                novoUtilizador.Password = password;
                novoUtilizador.Comentarios = comentarios;

                // Coloca o utilizador no nosso entity model
                database.AddToUtilizadores(novoUtilizador);
                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }

        public static void RemoverUtilizador(String nome)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(nome)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Procura na base de dados o utilizador que se pretende apagar
                var listaUtilizadores = from i in database.Utilizadores where i.Nome == nome select i;

                // Verifica se o utilizador existe
                if (listaUtilizadores.Count() != 1)
                {
                    throw new ArgumentException("O utilizador com o nome " + nome + " não existe.");
                }

                // Obtem o utilizador da lista de utilizadores obtida na pesquisa, como sabemos que só poderá ser 1 então podemos dizer que
                // queremos o primeiro utilizador da lista.
                var utilizador = listaUtilizadores.First();

                // Apaga o utilizador do entity model
                database.DeleteObject(utilizador);
                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }

        public static void EditarUtilizador(String nome, String password, String comentarios)
        {
            // Verificar se os argumentos sao validos
            if (String.IsNullOrEmpty(nome)) throw new ArgumentNullException();

            // Cria um objecto do entity model
            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                // Procura na base de dados o utilizador que se pretende apagar
                var listaUtilizadores = from i in database.Utilizadores where i.Nome == nome select i;

                // Verifica se o utilizador existe
                if (listaUtilizadores.Count() != 1)
                {
                    throw new ArgumentException("O utilizador com o nome " + nome + " não existe.");
                }

                // Obtem o utilizador da lista de utilizadores obtida na pesquisa, como sabemos que só poderá ser 1 então podemos dizer que
                // queremos o primeiro utilizador da lista.
                var utilizador = listaUtilizadores.First();

                // Efectua as alteracoes no utilizador
                utilizador.Nome = nome;
                utilizador.Password = password;
                utilizador.Comentarios = comentarios;

                // Guarda as alteracoes feitas ao entity model na base de dados
                database.SaveChanges();
            }
        }

        public static List<Utilizadores> ObterUtilizadores()
        {
            List<Utilizadores> result = new List<Utilizadores>();

            using (PPLWAREDBEntities database = new PPLWAREDBEntities())
            {
                var listaUtilizadores = from i in database.Utilizadores select i;

                foreach (var utilizador in listaUtilizadores)
                {
                    result.Add(utilizador);
                }
            }

            return result;
        }
    }
}
